@@ -12,11 +12,30 @@ reports ()
    player         *P;
    int             i;
    char *cap_gamename;
+   char *F;
+   static char     buf2[256];
    char *uncorrupted_address; /* <-----is a TEMPORARY FIX and will need
 					to be fixed properly at some point. */
 
    mkdir("reports", 0700);
+   sprintf(buf, "reports/%s", gamename);
+   mkdir(buf, 0700);
+   F = findfirst(buf);
+   while (F) {
+      sprintf(buf2, "reports/%s/%s", gamename, F);
+      unlink(buf2);
+      F = findnext();
+   }
+
    mkdir("nreports", 0700);
+   sprintf(buf, "nreports/%s", gamename);
+   mkdir(buf, 0700);
+   F = findfirst(buf);
+   while (F) {
+      sprintf(buf2, "nreports/%s/%s", gamename, F);
+      unlink(buf2);
+      F = findnext();
+   }
 
    reportfileno = 0;
    for (P = players; P; P = P->next)
