@@ -654,7 +654,7 @@ loadphase ()
                }
          if (p->routes[CG_EMPTY])
             for (g = P->groups; g; g = g->next)
-               if (g->where == p && g->type->cargo && g->type->drive && g->dist == 0 && g->loadtype == CG_EMPTY && !g->thefleet)
+               if (g->where == p && g->type->cargo && g->dist == 0 && g->loadtype == CG_EMPTY && !g->thefleet)
                   send(g, p->routes[CG_EMPTY]);
       }
 }
@@ -772,7 +772,7 @@ unloadphase ()
       if (p->owner)
          for (i = 0; i != CG_EMPTY; i++) {
             p2 = p->routes[i];
-            for (g = p->owner->groups; g; g = g->next)
+            for (g = p->owner->groups; g; g = g->next) {
                if (g->where == p2 &&
                    g->dist == 0 &&
                    g->loadtype == i &&
@@ -780,6 +780,12 @@ unloadphase ()
                    !(g->loadtype == CG_COL && g->where->owner &&
                      g->where->owner != p->owner))
                   unloadgroup(g, p->owner);
+	       if (p->owner->autounload &&
+		   (g->where == p) &&
+		   (g->dist == 0) &&
+		   (g->ships))
+                  unloadgroup(g, p->owner);
+	    }
          }
 }
 
@@ -921,6 +927,85 @@ producephase ()
       }
 }
 
+#ifdef __STDC__
+void 
+sortphase(void)
+#else
+void 
+sortphase()
+#endif
+{
+   group *g, *g2, *newgroup;
+   fleetname *fl;
+   player *P;
+   planet *Pl;
+   int first;
+   int HasBeenSorted;
+
+   first = 1;
+   HasBeenSorted = 0;
+   for (P=players; P; P=P->next) {
+      if (P->sortgroups) {
+         /* sorting for groups at your own planet */
+         for (Pl=planets; Pl; Pl=Pl->next) {
+            for (g=P->groups; g;g=g->next) 
+               if ((!g->thefleet)&&(g->where==Pl)&&(Pl->owner == P)) {
+                  newgroup = addgroup(g, newgroup, first);
+                  first = 0;
+                  HasBeenSorted = 1;
+               }
+            for (fl=P->fleetnames; fl; fl=fl->next)
+               for (g=P->groups; g;g=g->next) 
+                  if ((g->thefleet==fl)&&(g->where==Pl)&&(Pl->owner == P)) {
+                     newgroup = addgroup(g, newgroup, first);
+                     first = 0;
+                     HasBeenSorted = 1;
+                  }
+         }
+
+         /* sorting for groups at your somebody else's planet */
+         for (Pl=planets; Pl; Pl=Pl->next) {
+            for (g=P->groups; g;g=g->next) 
+               if ((!g->thefleet)&&(g->where==Pl)&&(Pl->owner != P)&&(!isuninhabited (P,Pl))) {
+                  newgroup = addgroup(g, newgroup, first);
+                  first = 0;
+                  HasBeenSorted = 1;
+               }
+            for (fl=P->fleetnames; fl; fl=fl->next)
+               for (g=P->groups; g;g=g->next) 
+                  if ((g->thefleet==fl)&&(g->where==Pl)&&(Pl->owner != P)&&(!isuninhabited (P,Pl))) {
+                     newgroup = addgroup(g, newgroup, first);
+                     first = 0;
+                     HasBeenSorted = 1;
+                  }
+         }
+
+         /* sorting for groups at uninhabitted planets */
+         for (Pl=planets; Pl; Pl=Pl->next) {
+            for (g=P->groups; g;g=g->next) 
+               if ((!g->thefleet)&&(g->where==Pl)&&(isuninhabited (P,Pl))) {
+                  newgroup = addgroup(g, newgroup, first);
+                  first = 0;
+                  HasBeenSorted = 1;
+               }
+            for (fl=P->fleetnames; fl; fl=fl->next)
+               for (g=P->groups; g;g=g->next) 
+                  if ((g->thefleet==fl)&&(g->where==Pl)&&(isuninhabited (P,Pl))) {
+                     newgroup = addgroup(g, newgroup, first);
+                     first = 0;
+                     HasBeenSorted = 1;
+                  }
+         }
+
+         if (HasBeenSorted) {
+            HasBeenSorted = 0;
+            P->groups = newgroup;
+         }
+      }
+      first = 1;
+   }
+}
+
 #ifdef __STDC__
 void 
 mistake (player * P, strlist * s, char *comment)
