@@ -536,11 +536,19 @@ int         j;
    g = findgroup (P,ns);
    fl = identify (P->fleetnames, ns);
    if (!g && !fl) {
-      mistake (P, *s,"Group or fleet not recognized");
+      mistake (P, *s,"Source Group or fleet not recognized");
       return;
    }
    if (fl) {
       fl2 = identify (P->fleetnames, getstr(0));
+
+      if (!fl2) {
+	mistake (P, *s, "Destination fleet not recognized");
+	return;
+      }
+      dist = 0.0;
+      dist2 = 0.0;
+      p2 = 0;
       for (g=P->groups; g; g=g->next) {
 	 if (g->thefleet == fl) {
 	    p = g->where;
@@ -559,7 +567,7 @@ int         j;
 	 mistake (P, *s, "Second fleet is in hyperspace");
 	 return;
       }
-      if (p != p2) {
+      if ((p != p2)&&(p2)) {
 	 mistake (P, *s, "Fleets are not at the same planet");
 	 return;
       }
@@ -796,6 +804,18 @@ int      i;
       P->fleettables = i;
       return;
    }
+   if (!strcmpl(ns, "sortgroups")) {
+      P->sortgroups = i;
+      return;
+   }
+   if (!strcmpl(ns, "prodtable")) {
+      P->prodtable = i;
+      return;
+   }
+   if (!strcmpl(ns, "autounload")) {
+      P->autounload = i;
+      return;
+   }
    if (!strcmpl(ns, "underscores")) {
       P->underscores = i;
       return;
@@ -1288,18 +1308,7 @@ char *InFile,*glist[MAXGAMES];
    if (!ordersfilename[0])
       return;
    unlink("send");
-   F = findfirst("reports");
-   while (F) {
-      sprintf(buf, "reports/%s", F);
-      unlink(buf);
-      F = findnext();
-   }
-   F = findfirst("nreports");
-   while (F) {
-      sprintf(buf, "nreports/%s", F);
-      unlink(buf);
-      F = findnext();
-   }
+
    while (!nextgame(glist) ) {
       f = Fopen(ordersfilename, "r");
       printf("Reading orders from file...\n");
@@ -1468,6 +1477,7 @@ char *InFile,*glist[MAXGAMES];
       producephase();
       unloadphase();
       joinphase();
+      sortphase();
       fleetphase ();
 
       reports();
